==> haskell-cassava-megaparsec-1.0.0-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cassava-megaparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cassava-megaparsec
version: 1.0.0
id: cassava-megaparsec-1.0.0-5eQk3Bp462UGERBzWDTX7G
key: cassava-megaparsec-1.0.0-5eQk3Bp462UGERBzWDTX7G
license: MIT
maintainer: Mark Karpov <markkarpov@openmailbox.org>
author: Mark Karpov <markkarpov@openmailbox.org>
homepage: https://github.com/stackbuilders/cassava-megaparsec
synopsis: Megaparsec parser of CSV files that plays nicely with Cassava
description:
    Megaparsec parser of CSV files that plays nicely with Cassava.
category: Text, Web, CSV, Parsing
abi: 250956e4fae8cdea55507be489a658cf
exposed: True
exposed-modules:
    Data.Csv.Parser.Megaparsec
import-dirs: /usr/lib/ghc-8.6.2/site-local/cassava-megaparsec-1.0.0
library-dirs: /usr/lib/ghc-8.6.2/site-local/cassava-megaparsec-1.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.2/cassava-megaparsec-1.0.0
hs-libraries: HScassava-megaparsec-1.0.0-5eQk3Bp462UGERBzWDTX7G
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    cassava-0.5.1.0-C3atDG2FK0L29cUyrxtlHx containers-0.6.0.1
    megaparsec-6.5.0-EUmv2cuuzifJ0XtF7esHmy
    unordered-containers-0.2.9.0-BISrknrydugK8yp2XIgTJd
    vector-0.12.0.1-BKWaeB2IPwRDyZEP11mv5m
haddock-interfaces: /usr/share/doc/haskell-cassava-megaparsec/html/cassava-megaparsec.haddock
haddock-html: /usr/share/doc/haskell-cassava-megaparsec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cassava-megaparsec-2.0.0-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cassava-megaparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cassava-megaparsec
version: 2.0.0
id: cassava-megaparsec-2.0.0-EXHkiue7ZotLav4iUsCTER
key: cassava-megaparsec-2.0.0-EXHkiue7ZotLav4iUsCTER
license: MIT
maintainer: Mark Karpov <markkarpov92@gmail.org>
author: Mark Karpov <markkarpov92@gmail.org>
homepage: https://github.com/stackbuilders/cassava-megaparsec
synopsis: Megaparsec parser of CSV files that plays nicely with Cassava
description:
    Megaparsec parser of CSV files that plays nicely with Cassava.
category: Text, Web, CSV, Parsing
abi: 60ab92f8b4e3593ca2653abfb756b01c
exposed: True
exposed-modules:
    Data.Csv.Parser.Megaparsec
import-dirs: /usr/lib/ghc-8.6.3/site-local/cassava-megaparsec-2.0.0
library-dirs: /usr/lib/ghc-8.6.3/site-local/cassava-megaparsec-2.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/cassava-megaparsec-2.0.0
hs-libraries: HScassava-megaparsec-2.0.0-EXHkiue7ZotLav4iUsCTER
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    cassava-0.5.1.0-2EdSgAHT2nJ4Vim7PvrXGa
    megaparsec-7.0.4-6kTw2XktLyrJEOPPrniUVY
    unordered-containers-0.2.9.0-BISrknrydugK8yp2XIgTJd
    vector-0.12.0.2-5G85DK6NPIx1LphnqJy7eO
haddock-interfaces: /usr/share/doc/haskell-cassava-megaparsec/html/cassava-megaparsec.haddock
haddock-html: /usr/share/doc/haskell-cassava-megaparsec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
